@@ -1,9 +1,10 @@
 from core.oracle.Prediction import Prediction
+from exchange.rate.ExchangeRateHolder import ExchangeRateHolder
 
 
 class Oracle:
 
-    def set_data(self, data):
+    def set_exchange_rates(self, exchange_rates: ExchangeRateHolder):
         pass
 
     def predict(self, instrument) -> Prediction:
